# telealchemy

[![PyPi Package Version](https://img.shields.io/pypi/v/telealchemy.svg?style=flat-square)](https://pypi.python.org/pypi/telealchemy)
[![Python](https://img.shields.io/pypi/pyversions/telealchemy)](https://pypi.python.org/pypi/telealchemy)
[![repository size](https://img.shields.io/github/repo-size/alteralt/telealchemy)](https://github.com/alteralt/telealchemy)
[![Downloads](https://img.shields.io/pypi/dm/telealchemy)](https://pypi.python.org/pypi/telealchemy)

# How install

```sh
pip install telealchemy
```
